@@ -4,6 +4,8 @@ from __future__ import (
 
 import logging
 from collections.abc import (
+    Iterable,
+    Mapping,
     MutableSet,
 )
 from datetime import (
@@ -15,7 +17,6 @@ from datetime import (
 )
 from typing import (
     Any,
-    Iterable,
     TypeVar,
     Union,
     get_args,
@@ -117,6 +118,9 @@ class AvroDataDecoder:
             if issubclass(type_, datetime):
                 return self._cast_datetime(data)
 
+            if issubclass(type_, timedelta):
+                return self._cast_timedelta(data)
+
             if issubclass(type_, date):
                 return self._cast_date(data)
 
@@ -197,6 +201,14 @@ class AvroDataDecoder:
             return datetime(1970, 1, 1, tzinfo=timezone.utc) + data * timedelta(microseconds=1)
         raise DataDecoderTypeException(datetime, data)
 
+    @staticmethod
+    def _cast_timedelta(data: Any) -> timedelta:
+        if isinstance(data, timedelta):
+            return data
+        if isinstance(data, int):
+            return timedelta(microseconds=data)
+        raise DataDecoderTypeException(timedelta, data)
+
     @staticmethod
     def _cast_uuid(data: Any) -> UUID:
         if isinstance(data, UUID):
@@ -240,6 +252,9 @@ class AvroDataDecoder:
         if origin_type is list:
             return self._cast_list(data, type_)
 
+        if origin_type is set:
+            return self._cast_set(data, type_)
+
         if origin_type is dict:
             return self._cast_dict(data, type_)
 
@@ -250,14 +265,21 @@ class AvroDataDecoder:
 
     def _cast_list(self, data: list, type_values: Any) -> list[Any]:
         type_values = get_args(type_values)[0]
-        if not isinstance(data, list):
+        if not isinstance(data, Iterable):
             raise DataDecoderTypeException(list, data)
 
         return list(self._cast_iterable(data, type_values))
 
+    def _cast_set(self, data: set, type_values: Any) -> set[Any]:
+        type_values = get_args(type_values)[0]
+        if not isinstance(data, Iterable):
+            raise DataDecoderTypeException(set, data)
+
+        return set(self._cast_iterable(data, type_values))
+
     def _cast_dict(self, data: dict, type_: type) -> dict[str, Any]:
         type_keys, type_values = get_args(type_)
-        if not isinstance(data, dict):
+        if not isinstance(data, Mapping):
             raise DataDecoderTypeException(dict, data)
 
         if type_keys is not str:
