@@ -1,10 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from .abc import (
     MinosSnapshot,
 )
@@ -16,6 +9,8 @@ from .memory import (
 )
 from .pg import (
     PostgreSqlSnapshot,
-    PostgreSqlSnapshotBuilder,
+    PostgreSqlSnapshotQueryBuilder,
+    PostgreSqlSnapshotReader,
     PostgreSqlSnapshotSetup,
+    PostgreSqlSnapshotWriter,
 )
