@@ -1,27 +1,22 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from __future__ import (
     annotations,
 )
 
-import abc
+from abc import (
+    ABC,
+    abstractmethod,
+)
 from typing import (
     Any,
-    NoReturn,
     Optional,
 )
 
 
-class MinosStorage(abc.ABC):
+class MinosStorage(ABC):
     """Minos Storage interface."""
 
-    @abc.abstractmethod
-    def add(self, **kwargs) -> NoReturn:
+    @abstractmethod
+    def add(self, **kwargs) -> None:
         """Store a value.
 
         :param kwargs: Additional named arguments.
@@ -29,7 +24,7 @@ class MinosStorage(abc.ABC):
         """
         raise NotImplementedError
 
-    @abc.abstractmethod
+    @abstractmethod
     def get(self, **kwargs) -> Optional[Any]:
         """Get the stored value..
 
@@ -38,8 +33,8 @@ class MinosStorage(abc.ABC):
         """
         raise NotImplementedError
 
-    @abc.abstractmethod
-    def delete(self, **kwargs) -> NoReturn:
+    @abstractmethod
+    def delete(self, **kwargs) -> None:
         """Delete the stored value.
 
         :param kwargs:
@@ -47,8 +42,8 @@ class MinosStorage(abc.ABC):
         """
         raise NotImplementedError
 
-    @abc.abstractmethod
-    def update(self, **kwargs) -> NoReturn:
+    @abstractmethod
+    def update(self, **kwargs) -> None:
         """Update the stored value.
 
         :param kwargs: Additional named arguments.
@@ -57,7 +52,7 @@ class MinosStorage(abc.ABC):
         raise NotImplementedError
 
     @classmethod
-    @abc.abstractmethod
+    @abstractmethod
     def build(cls, **kwargs) -> MinosStorage:
         """Build a new instance.
 
